/*
 * Copyright 2010-2012 Roman Yepishev <roman.yepishev@ubuntu.com>
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using GLib;

namespace Util {

    public string format_time(int64 seconds) {
        GLib.Time t = GLib.Time();
        t.second = (int)seconds;
        t.mktime();
        return t.format("%T");
    }

    public string format_transfer_rate(int64 val) {
        string[] units = {
            // Binary suffixes for data transfer rate
            // Kibibytes per second (not kilobits)
            _("B/s"), _("KiB/s"), _("MiB/s"), _("GiB/s")
        };

        // Transfer rate format: %1$.0f - value, %2$s - unit
        // Leave this as is if "100 MiB/s" is correct in your language
        return _format(val, units, 1024, _("%1$3.0f %2$s"));
    }

    public static string format_data(int64 val) {
        string[] units = {
            // Binary suffixes for data volume (kibibytes, mebibytes etc.)
            _("bytes"), _("KiB"), _("MiB"), _("GiB"), _("TiB")
        };

        // Data volume format: %1$.1f - value, %2$s - unit
        // Leave this as is if "100 MiB" is correct in your language
        return _format(val, units, 1024, _("%1$3.1f %2$s"));
    }

    private static string _format(int64 val, string[] units,
                                  int64 divider, string format) {
        double approx_value = (double)val;
        string current_unit = units[0];

        int units_length = units.length;
        int unit_id = 0;

        foreach (var unit in units) {
            unit_id += 1;
            current_unit = unit;
            if (approx_value >= divider && unit_id != units_length) {
                approx_value /= divider;
            }
            else {
                break;
            }
        }
        
        return format.printf(approx_value, current_unit);
    }
}

